@@ -1,4 +1,6 @@
+#define R_NO_REMAP
 #include <Rinternals.h>
+#undef R_NO_REMAP
 
 #include <libxml/parser.h>
 #include <libxml/HTMLparser.h>
@@ -194,13 +196,13 @@ extern "C" SEXP doc_parse_file(
   if (as_html) {
     pDoc = htmlReadFile(
       path,
-      strncmp(encoding, "", 0) == 0 ? NULL : encoding,
+      encoding[0] == '\0' ? NULL : encoding,
       options
     );
   } else {
     pDoc = xmlReadFile(
       path,
-      strncmp(encoding, "", 0) == 0 ? NULL : encoding,
+      encoding[0] == '\0' ? NULL : encoding,
       options
     );
   }
@@ -222,7 +224,7 @@ extern "C" SEXP doc_parse_raw(
 
   BEGIN_CPP
   std::string encoding(CHAR(STRING_ELT(encoding_sxp, 0)));
-  std::string base_url(CHAR(STRING_ELT(encoding_sxp, 0)));
+  std::string base_url(CHAR(STRING_ELT(base_url_sxp, 0)));
   bool as_html = LOGICAL(as_html_sxp)[0];
   int options = INTEGER(options_sxp)[0];
 
@@ -277,7 +279,7 @@ extern "C" SEXP  doc_url(SEXP doc_sxp) {
 
   XPtrDoc doc(doc_sxp);
   if (doc->URL == NULL) {
-    return NA_STRING;
+    return Rf_ScalarString(NA_STRING);
   }
 
   SEXP out = PROTECT(Rf_allocVector(STRSXP, 1));
